Comprimir

TAR
Comprimir:
tar -cvf archivo.tar ficheros
Descomprimir:
tar -xvf archivo.tar
Para ver el contenido:
tar -tzf archivo.tar
RAR
Comprimir:
rar -a archivo.rar ficheros
Descomprimir:
rar -x archivo.rar
Para ver el contenido:
rar -l archivo.rar
rar -v archivo.rar
ZIP
Comprimir:
zip archivo.zip ficheros
Descomprimir:
unzip archivo.zip
Para ver el contenido:
unzip -v archivo.zip
GZ
Comprimir:
gzip -9 fichero
Descomprimir:
gzip -d fichero.gz
Para buscar el contenido:
-c: Contar cuantos hay.
-i: Ignorar mayúsculas y minúsculas.
-n: Muestra el número de la línea.
-v: Que no contanga.
-l: Nombre del fichero.
zgrep -ALGO ALGO.gz
TAR.BZ2
Comprimir:
tar -c ficheros | bzip2 > archivo.tar.bz2
Descomprimir:
bzip2 -dc archivo.tar.bz2 | tar -xv
Para ver el contenido:
bzip2 -dc archivo.tar.bz2 | tar -t
BZ2
Comprimir:
bzip fichero
Descomprimir:
bzip2 -d fichero.bz2